@@ -1,40 +1,36 @@
-from typing import Any, Dict
-
 import pandas as pd
 
-from mqboost.base import FUNC_TYPE, ModelName, MQStr, TypeName, ValidationException
+from mqboost.base import FUNC_TYPE, ModelName, ParamsLike, TypeName
 
 
 def set_monotone_constraints(
-    params: Dict[str, Any],
+    params: ParamsLike,
     columns: pd.Index,
     model_name: ModelName,
-) -> Dict[str, Any]:
+) -> ParamsLike:
     """
     Set monotone constraints in params
     Args:
-        params (Dict[str, Any])
+        params (ParamsLike)
         columns (pd.Index)
         model_name (ModelName)
     Raises:
         ValidationException: when "objective" is in params.keys()
     Returns:
-        Dict[str, Any]
+        ParamsLike
     """
+    MONOTONE_CONSTRAINTS: str = "monotone_constraints"
+
     constraints_fucs = FUNC_TYPE.get(model_name).get(TypeName.constraints_type)
-    if MQStr.obj.value in params:
-        raise ValidationException(
-            "The parameter named 'objective' must be excluded in params"
-        )
     _params = params.copy()
-    if MQStr.mono.value in _params:
-        _monotone_constraints = list(_params[MQStr.mono.value])
+    if MONOTONE_CONSTRAINTS in _params:
+        _monotone_constraints = list(_params[MONOTONE_CONSTRAINTS])
         _monotone_constraints.append(1)
-        _params.update({MQStr.mono.value: constraints_fucs(_monotone_constraints)})
+        _params.update({MONOTONE_CONSTRAINTS: constraints_fucs(_monotone_constraints)})
     else:
         _params.update(
             {
-                MQStr.mono.value: constraints_fucs(
+                MONOTONE_CONSTRAINTS: constraints_fucs(
                     [1 if "_tau" == col else 0 for col in columns]
                 )
             }
